@@ -7,15 +7,16 @@ import torch.nn as nn
 from pytorch_lightning import LightningModule, Trainer
 from pytorch_lightning.utilities.apply_func import apply_to_collection
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
+from torch import Tensor
 
 from pl_bolts.callbacks.verification.base import VerificationBase, VerificationCallbackBase
 
 
 class BatchGradientVerification(VerificationBase):
-    """
-    Checks if a model mixes data across the batch dimension.
-    This can happen if reshape- and/or permutation operations are carried out in the wrong order or
-    on the wrong tensor dimensions.
+    """Checks if a model mixes data across the batch dimension.
+
+    This can happen if reshape- and/or permutation operations are carried out in the wrong order or on the wrong tensor
+    dimensions.
     """
 
     NORM_LAYER_CLASSES = (
@@ -33,8 +34,7 @@ class BatchGradientVerification(VerificationBase):
         output_mapping: Optional[Callable] = None,
         sample_idx: int = 0,
     ) -> bool:
-        """
-        Runs the test for data mixing across the batch.
+        """Runs the test for data mixing across the batch.
 
         Arguments:
             input_array: A dummy input for the model. Can be a tuple or dict in case the model takes
@@ -83,8 +83,8 @@ class BatchGradientVerification(VerificationBase):
 
 
 class BatchGradientVerificationCallback(VerificationCallbackBase):
-    """
-    The callback version of the :class:`BatchGradientVerification` test.
+    """The callback version of the :class:`BatchGradientVerification` test.
+
     Verification is performed right before training begins.
     """
 
@@ -130,9 +130,8 @@ class BatchGradientVerificationCallback(VerificationCallbackBase):
             self._raise()
 
 
-def default_input_mapping(data: Any) -> List[torch.Tensor]:
-    """
-    Finds all tensors in a (nested) collection that have the same batch size.
+def default_input_mapping(data: Any) -> List[Tensor]:
+    """Finds all tensors in a (nested) collection that have the same batch size.
 
     Args:
         data: a tensor or a collection of tensors (tuple, list, dict, etc.).
@@ -151,17 +150,15 @@ def default_input_mapping(data: Any) -> List[torch.Tensor]:
     torch.Size([3, 2])
     """
     tensors = collect_tensors(data)
-    batches: List[torch.Tensor] = []
+    batches: List[Tensor] = []
     for tensor in tensors:
         if tensor.ndim > 0 and (not batches or tensor.size(0) == batches[0].size(0)):
             batches.append(tensor)
     return batches
 
 
-def default_output_mapping(data: Any) -> torch.Tensor:
-    """
-    Pulls out all tensors in a output collection and combines them into one big batch
-    for verification.
+def default_output_mapping(data: Any) -> Tensor:
+    """Pulls out all tensors in a output collection and combines them into one big batch for verification.
 
     Args:
         data: a tensor or a (nested) collection of tensors (tuple, list, dict, etc.).
@@ -181,7 +178,7 @@ def default_output_mapping(data: Any) -> torch.Tensor:
         >>> result.shape
         torch.Size([3, 7])
     """
-    if isinstance(data, torch.Tensor):
+    if isinstance(data, Tensor):
         return data
 
     batches = default_input_mapping(data)
@@ -191,22 +188,21 @@ def default_output_mapping(data: Any) -> torch.Tensor:
     return combined
 
 
-def collect_tensors(data: Any) -> List[torch.Tensor]:
-    """ Filters all tensors in a collection and returns them in a list. """
+def collect_tensors(data: Any) -> List[Tensor]:
+    """Filters all tensors in a collection and returns them in a list."""
     tensors = []
 
-    def collect_batches(tensor: torch.Tensor) -> torch.Tensor:
+    def collect_batches(tensor: Tensor) -> Tensor:
         tensors.append(tensor)
         return tensor
 
-    apply_to_collection(data, dtype=torch.Tensor, function=collect_batches)
+    apply_to_collection(data, dtype=Tensor, function=collect_batches)
     return tensors
 
 
 @contextmanager
 def selective_eval(model: nn.Module, layer_types: Iterable[Type[nn.Module]]) -> None:
-    """
-    A context manager that sets all requested types of layers to eval mode. This method uses an ``isinstance``
+    """A context manager that sets all requested types of layers to eval mode. This method uses an ``isinstance``
     check, so all subclasses are also affected.
 
     Args:
