@@ -10,9 +10,10 @@ from pl_bolts.datasets.dummy_dataset import (
     RandomDictDataset,
     RandomDictStringDataset,
 )
-from pl_bolts.datasets.imagenet_dataset import extract_archive, parse_devkit_archive, UnlabeledImagenet
+from pl_bolts.datasets.emnist_dataset import BinaryEMNIST
+from pl_bolts.datasets.imagenet_dataset import UnlabeledImagenet, extract_archive, parse_devkit_archive
 from pl_bolts.datasets.kitti_dataset import KittiDataset
-from pl_bolts.datasets.mnist_dataset import BinaryMNIST
+from pl_bolts.datasets.mnist_dataset import MNIST, BinaryMNIST
 from pl_bolts.datasets.ssl_amdim_datasets import CIFAR10Mixed, SSLDatasetMixin
 
 __all__ = [
@@ -22,6 +23,7 @@ __all__ = [
     "ConcatDataset",
     "DummyDataset",
     "DummyDetectionDataset",
+    "MNIST",
     "RandomDataset",
     "RandomDictDataset",
     "RandomDictStringDataset",
@@ -32,9 +34,10 @@ __all__ = [
     "BinaryMNIST",
     "CIFAR10Mixed",
     "SSLDatasetMixin",
+    "BinaryEMNIST",
 ]
 
 # TorchVision hotfix https://github.com/pytorch/vision/issues/1938
 opener = urllib.request.build_opener()
-opener.addheaders = [('User-agent', 'Mozilla/5.0')]
+opener.addheaders = [("User-agent", "Mozilla/5.0")]
 urllib.request.install_opener(opener)
