@@ -39,8 +39,8 @@ class SwAV(LightningModule):
         queue_length: int = 0,  # must be divisible by total batch-size
         queue_path: str = "queue",
         epoch_queue_starts: int = 15,
-        crops_for_assign: list = [0, 1],
-        nmb_crops: list = [2, 6],
+        crops_for_assign: tuple = (0, 1),
+        nmb_crops: tuple = (2, 6),
         first_conv: bool = True,
         maxpool1: bool = True,
         optimizer: str = "adam",
@@ -185,7 +185,7 @@ class SwAV(LightningModule):
 
         self.use_the_queue = False
 
-    def on_train_epoch_end(self, outputs) -> None:
+    def on_train_epoch_end(self) -> None:
         if self.queue is not None:
             torch.save({"queue": self.queue}, self.queue_path)
 
@@ -255,7 +255,7 @@ class SwAV(LightningModule):
         self.log("val_loss", loss, on_step=False, on_epoch=True)
         return loss
 
-    def exclude_from_wt_decay(self, named_params, weight_decay, skip_list=["bias", "bn"]):
+    def exclude_from_wt_decay(self, named_params, weight_decay, skip_list=("bias", "bn")):
         params = []
         excluded_params = []
 
@@ -558,7 +558,7 @@ def cli_main():
         max_steps=None if args.max_steps == -1 else args.max_steps,
         gpus=args.gpus,
         num_nodes=args.num_nodes,
-        distributed_backend="ddp" if args.gpus > 1 else None,
+        accelerator="ddp" if args.gpus > 1 else None,
         sync_batchnorm=True if args.gpus > 1 else False,
         precision=32 if args.fp32 else 16,
         callbacks=callbacks,
